@@ -1,27 +1,27 @@
 #' nlm_mosaicfield
 #'
-#' @description Simulate a mosaic random field neutral landscape model.
+#' @description Simulates a mosaic random field neutral landscape model.
 #'
 #' @param ncol [\code{numerical(1)}]\cr
-#' Number of columns for the raster.
+#' Number of columns forming the raster.
 #' @param nrow  [\code{numerical(1)}]\cr
-#' Number of rows for the raster.
+#' Number of rows forming the raster.
 #' @param resolution  [\code{numerical(1)}]\cr
 #' Resolution of the raster.
 #' @param n [\code{numerical(1)}]\cr
-#' Number of steps that the mosaic random field algorithm is run
+#' Number of steps over which the mosaic random field algorithm is run
 #' @param mosaic_mean [\code{numerical(1)}]\cr
 #' Mean value of the mosaic displacement distribution
 #' @param mosaic_sd [\code{numerical(1)}]\cr
 #' Standard deviation of the mosaic displacement distribution
 #' @param collect [\code{logical(1)}]\cr
-#' return RasterBrick of all steps 1:n
+#' return \code{RasterBrick} of all steps 1:\code{n}
 #' @param infinit [\code{logical(1)}]\cr
 #' return raster of the random mosaic field algorithm with infinite steps
 #' @param rescale [\code{logical(1)}]\cr
 #' If \code{TRUE} (default), the values are rescaled between 0-1.
 #'
-#' @return RasterLayer or List with RasterLayer(s) and/or RasterBrick
+#' @return RasterLayer or List with RasterLayer/s and/or RasterBrick
 #'
 #' @references
 #' Schwab, Dimitri, Martin Schlather, and Jürgen Potthoff. "A general class of
@@ -39,7 +39,7 @@
 #'                                 collect = FALSE)
 #' \dontrun{
 #' # visualize the NLM
-#' util_plot(mosaic_field)
+#' rasterVis::levelplot(mosaic_field, margin = FALSE, par.settings = rasterVis::viridisTheme())
 #' }
 #'
 #' @aliases nlm_mosaicfield
@@ -57,7 +57,6 @@ nlm_mosaicfield <- function(ncol,
                             collect     = FALSE,
                             infinit     = FALSE,
                             rescale     = TRUE) {
-
   # Check function arguments ----
   checkmate::assert_count(ncol, positive = TRUE)
   checkmate::assert_count(nrow, positive = TRUE)
@@ -76,27 +75,22 @@ nlm_mosaicfield <- function(ncol,
       spatstat::rpoislinetess(4),
       stats::rnorm,
       dimyx = c(nrow, ncol),
-      rgenargs = list(
-        mean = mosaic_mean,
-        sd = mosaic_sd
-      )
+      rgenargs = list(mean = mosaic_mean,
+                      sd = mosaic_sd)
     )
 
     if (isTRUE(collect)) {
-      i <- 2
       mosaicfield_list <- list()
       mosaicfield_list[[1]] <- mosaicfield_result
     }
 
-    for (i in 1:n) {
+    for (i in 2:n) {
       mosaicfield_n <- spatstat::rMosaicField(
         spatstat::rpoislinetess(4),
         stats::rnorm,
         dimyx = c(nrow, ncol),
-        rgenargs = list(
-          mean = mosaic_mean,
-          sd = mosaic_sd
-        )
+        rgenargs = list(mean = mosaic_mean,
+                        sd = mosaic_sd)
       )
 
       mosaicfield_result <- mosaicfield_result + mosaicfield_n
@@ -109,10 +103,9 @@ nlm_mosaicfield <- function(ncol,
     }
 
     # coerce spatstat image to raster and set proper resolution ----
-    mosaicfield_df <- as.data.frame(mosaicfield_result)
-    sp::coordinates(mosaicfield_df) <- ~ x + y
-    sp::gridded(mosaicfield_df) <- TRUE
-    mosaicfield_raster <- raster::raster(mosaicfield_df)
+    mosaicfield_raster <- raster::rasterFromXYZ(
+      as.data.frame(mosaicfield_result))
+
     raster::extent(mosaicfield_raster) <- c(
       0,
       ncol(mosaicfield_raster) * resolution,
@@ -129,29 +122,30 @@ nlm_mosaicfield <- function(ncol,
 
     if (isTRUE(collect)) {
       names(mosaicfield_list) <- seq_along(mosaicfield_list)
-      mosaicfield_list <- purrr::map(seq_along(mosaicfield_list), function(i) {
-        mosaicfield_list[[i]] <- mosaicfield_list[[i]] / sqrt(i)
-      })
+      mosaicfield_list <-
+        purrr::map(seq_along(mosaicfield_list), function(i) {
+          mosaicfield_list[[i]] <- mosaicfield_list[[i]] / sqrt(i)
+        })
 
-      mosaicfield_list <- purrr::map(seq_along(mosaicfield_list), function(i) {
+      mosaicfield_list <-
+        purrr::map(seq_along(mosaicfield_list), function(i) {
+          # coerce spatstat image list to raster and set proper resolution ----
+          mosaicfield_list[[i]] <- raster::rasterFromXYZ(
+            as.data.frame(mosaicfield_list[[i]]))
 
-        # coerce spatstat image list to raster and set proper resolution ----
-        mosaicfield_list[[i]] <- as.data.frame(mosaicfield_list[[i]])
-        sp::coordinates(mosaicfield_list[[i]]) <- ~ x + y
-        sp::gridded(mosaicfield_list[[i]]) <- TRUE
-        mosaicfield_list[[i]] <- raster::raster(mosaicfield_list[[i]])
-        raster::extent(mosaicfield_list[[i]]) <- c(
-          0,
-          ncol(mosaicfield_list[[i]]) * resolution,
-          0,
-          nrow(mosaicfield_list[[i]]) * resolution
-        )
+          raster::extent(mosaicfield_list[[i]]) <- c(
+            0,
+            ncol(mosaicfield_list[[i]]) * resolution,
+            0,
+            nrow(mosaicfield_list[[i]]) * resolution
+          )
 
-        mosaicfield_list[[i]]
-      })
+          mosaicfield_list[[i]]
+        })
 
       mosaicfields_brick <- raster::brick(mosaicfield_list)
-      names(mosaicfields_brick) <- paste("Step: ", seq_along(mosaicfield_list))
+      names(mosaicfields_brick) <-
+        paste("Step: ", seq_along(mosaicfield_list))
 
       # Rescale values to 0-1
       if (rescale == TRUE) {
@@ -164,17 +158,21 @@ nlm_mosaicfield <- function(ncol,
   }
 
   if (isTRUE(infinit)) {
-
     # INFINITE STEPS:
-    X <- spatstat::rLGCP("exp", 4, var = 1, dimyx = c(nrow, ncol),
-                         scale = .2, saveLambda = TRUE)
+    X <- spatstat::rLGCP(
+      "exp",
+      4,
+      var = 1,
+      dimyx = c(nrow, ncol),
+      scale = .2,
+      saveLambda = TRUE
+    )
     mosaicfield_inf <- RandomFields::log(attr(X, "Lambda"))
 
     # coerce spatstat image to raster and set proper resolution ----
-    mosaicfield_df <- as.data.frame(mosaicfield_inf)
-    sp::coordinates(mosaicfield_df) <- ~ x + y
-    sp::gridded(mosaicfield_df) <- TRUE
-    mosaicfield_raster <- raster::raster(mosaicfield_df)
+    mosaicfield_raster <-
+      raster::rasterFromXYZ(as.data.frame(mosaicfield_inf))
+
     raster::extent(mosaicfield_raster) <- c(
       0,
       ncol(mosaicfield_raster) * resolution,
